@@ -4,8 +4,8 @@
   
   Authors: Marek Kokot
   
-  Version: 3.2.3
-  Date   : 2023-12-08
+  Version: 3.2.4
+  Date   : 2024-02-09
 */
 
 #include "parser.h"
@@ -28,7 +28,7 @@ CParser::CParser(const std::string& src):
 		exit(1);
 	}
 	//input_line_pattern = "\\s*(\\w*)\\s*=\\s*(.*)$";
-	input_line_pattern = "^\\s*([\\w-+]*)\\s*=\\s*(.*)$";
+	input_line_pattern = "^\\s*([\\w+-]*)\\s*=\\s*(.*)$";
 	output_line_pattern = "^\\s*(.*)\\s*=\\s*(.*)$"; //TODO: consider valid file name	
 	empty_line_pattern = "^\\s*$";
 }
